@@ -3,6 +3,8 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
 # API of the pyiron_base module - in alphabetical order
+# Internal init
+import pyiron_base._version
 from pyiron_base.interfaces.factory import PyironFactory
 from pyiron_base.interfaces.has_groups import HasGroups
 from pyiron_base.interfaces.has_hdf import HasHDF
@@ -29,6 +31,11 @@ from pyiron_base.jobs.master.generic import GenericMaster, get_function_from_str
 from pyiron_base.jobs.master.interactivewrapper import InteractiveWrapper
 from pyiron_base.jobs.master.list import ListMaster
 from pyiron_base.jobs.master.parallel import JobGenerator, ParallelMaster
+from pyiron_base.maintenance.generic import (
+    LocalMaintenance,
+    Maintenance,
+    add_module_conversion,
+)
 from pyiron_base.project.decorator import job
 from pyiron_base.project.external import Notebook, dump, load
 from pyiron_base.project.generic import Creator, Project
@@ -36,24 +43,18 @@ from pyiron_base.state import state
 from pyiron_base.state.install import install_dialog
 from pyiron_base.state.settings import Settings
 from pyiron_base.storage.datacontainer import DataContainer
+from pyiron_base.storage.filedata import FileData, FileDataTemplate, load_file
 from pyiron_base.storage.flattenedstorage import FlattenedStorage
 from pyiron_base.storage.has_stored_traits import HasStoredTraits
 from pyiron_base.storage.hdfio import FileHDFio, ProjectHDFio
 from pyiron_base.storage.inputlist import InputList
 from pyiron_base.storage.parameters import GenericParameters
-from pyiron_base.utils.jedi import fix_ipython_autocomplete
 from pyiron_base.utils.parser import Logstatus, extract_data_from_file
 
-# Internal init
-from ._version import get_versions
-
 Project.register_tools("base", BaseTools)
 
 # Set version of pyiron_base
-__version__ = get_versions()["version"]
-
-# Jedi fix
-fix_ipython_autocomplete()
+__version__ = pyiron_base._version.__version__
 
 # Dynamic job class definition is no longer supported in pyiron_base >=0.7.0
 warn_dynamic_job_classes(
@@ -79,6 +80,7 @@ __all__ = [
     GenericJob,
     InteractiveBase,
     JobStatus,
+    job,
     job_status_successful_lst,
     job_status_finished_lst,
     job_status_lst,
@@ -108,4 +110,10 @@ __all__ = [
     HasGroups,
     HasHDF,
     Toolkit,
+    add_module_conversion,
+    LocalMaintenance,
+    Maintenance,
+    load_file,
+    FileDataTemplate,
+    FileData,
 ]
