@@ -88,6 +88,7 @@ class TestWithProject(PyironTestCase, ABC):
     def setUpClass(cls):
         super().setUpClass()
         print("TestWithProject: Setting up test project")
+        reset_configuration()
         cls.project_path = getfile(cls)[:-3].replace("\\", "/")
         cls.file_location, cls.project_name = os.path.split(cls.project_path)
         cls.project = Project(cls.project_path)
@@ -178,3 +179,21 @@ _TO_SKIP = [
     TestWithCleanProject,
     TestWithFilledProject,
 ]
+
+
+def reset_configuration():
+    current_path = os.path.abspath(os.path.curdir)
+    top_level_path = current_path.replace("\\", "/")
+    resource_path = os.path.join(current_path, "tests", "static").replace("\\", "/")
+    pyiron_config = os.path.expanduser("~/.pyiron").replace("\\", "/")
+    if not os.path.exists(pyiron_config):
+        with open(pyiron_config, "w") as f:
+            f.writelines(
+                [
+                    "[DEFAULT]\n",
+                    "CONFIG_FILE_PERMISSIONS_WARNING = False\n",
+                    "TOP_LEVEL_DIRS = " + top_level_path + "\n",
+                    "RESOURCE_PATHS = " + resource_path + "\n",
+                ]
+            )
+        state.update()
