@@ -235,28 +235,6 @@ class DatabaseAccess(IsDatabase):
             delay=0.1,
             delay_factor=2,
         )
-        self._view_mode = False
-
-    def _get_view_mode(self) -> bool:
-        return self._view_mode
-
-    @IsDatabase.view_mode.setter
-    def view_mode(self, value: bool) -> None:
-        """
-        Set view_mode - if view_mode is enable pyiron has read only access to the database.
-
-        Args:
-            value (bool): TRUE or FALSE
-        """
-        if isinstance(value, bool):
-            self._view_mode = value
-        else:
-            raise TypeError("Viewmode can only be TRUE or FALSE.")
-
-    @IsDatabase.viewer_mode.setter
-    @deprecate("use view_mode")
-    def viewer_mode(self, value: bool) -> None:
-        self.view_mode = value
 
     def _job_dict(
         self,
@@ -281,7 +259,7 @@ class DatabaseAccess(IsDatabase):
             element_lst (list): list of elements required in the chemical formular - by default None
 
         Returns:
-            list: the function returns a list of dicts like get_items_sql, but it does not format datetime:
+            list: the function returns a list of dicts, but it does not format datetime:
                  [{'chemicalformula': u'Ni108',
                   'computer': u'mapc157',
                   'hamilton': u'LAMMPS',
@@ -312,6 +290,26 @@ class DatabaseAccess(IsDatabase):
                   'username': u'test'},.......]
 
         """
+        if not self._sql_lite:
+
+            def escape(s, escape_char="\\", special_chars="_%"):
+                """Insert escape_char in front of special_chars, unless present.
+
+                Handles the cases where s already contains escaped characters,
+                including the escape character itself.
+
+                Defaults for LIKE in SQL statements."""
+                for c in special_chars:
+                    if c in s:
+                        s = s.replace(escape_char + c, c)
+                    s = s.replace(c, escape_char + c)
+                return s
+
+        else:
+
+            def escape(s, escape_char="\\", special_chars="_%"):
+                return s
+
         dict_clause = {}
         # FOR GET_ITEMS_SQL: clause = []
         if user is not None:
@@ -334,7 +332,7 @@ class DatabaseAccess(IsDatabase):
         if project_path == "./":
             project_path = ""
         if recursive:
-            dict_clause["project"] = str(project_path) + "%"
+            dict_clause["project"] = escape(str(project_path)) + "%"
         else:
             dict_clause["project"] = str(project_path)
         if sub_job_name is None:
@@ -459,20 +457,17 @@ class DatabaseAccess(IsDatabase):
         Returns:
 
         """
-        if not self._view_mode:
-            if isinstance(col_name, list):
-                col_name = col_name[-1]
-            if isinstance(col_type, list):
-                col_type = col_type[-1]
-            self.conn.execute(
-                text(
-                    "ALTER TABLE %s ADD COLUMN %s %s"
-                    % (self.simulation_table.name, col_name, col_type)
-                )
+        if isinstance(col_name, list):
+            col_name = col_name[-1]
+        if isinstance(col_type, list):
+            col_type = col_type[-1]
+        self.conn.execute(
+            text(
+                "ALTER TABLE %s ADD COLUMN %s %s"
+                % (self.simulation_table.name, col_name, col_type)
             )
-            self.conn.commit()
-        else:
-            raise PermissionError("Not avilable in viewer mode.")
+        )
+        self.conn.commit()
 
     def change_column_type(
         self, col_name: Union[str, List[str]], col_type: Union[str, List[str]]
@@ -487,114 +482,17 @@ class DatabaseAccess(IsDatabase):
         Returns:
 
         """
-        if not self._view_mode:
-            if isinstance(col_name, list):
-                col_name = col_name[-1]
-            if isinstance(col_type, list):
-                col_type = col_type[-1]
-            self.conn.execute(
-                text(
-                    "ALTER TABLE %s ALTER COLUMN %s TYPE %s"
-                    % (self.simulation_table.name, col_name, col_type)
-                )
+        if isinstance(col_name, list):
+            col_name = col_name[-1]
+        if isinstance(col_type, list):
+            col_type = col_type[-1]
+        self.conn.execute(
+            text(
+                "ALTER TABLE %s ALTER COLUMN %s TYPE %s"
+                % (self.simulation_table.name, col_name, col_type)
             )
-            self.conn.commit()
-        else:
-            raise PermissionError("Not avilable in viewer mode.")
-
-    def get_items_sql(
-        self, where_condition: Optional[str] = None, sql_statement: Optional[str] = None
-    ) -> List[dict]:
-        """
-        Submit an SQL query to the database
-
-        Args:
-            where_condition (str): SQL where query, query like: "project LIKE 'lammps.phonons.Ni_fcc%'"
-            sql_statement (str): general SQL query, normal SQL statement
-
-        Returns:
-            list: get a list of dictionaries, where each dictionary represents one item of the table like:
-                 [{u'chemicalformula': u'BO',
-                  u'computer': u'localhost',
-                  u'hamilton': u'VAMPS',
-                  u'hamversion': u'1.1',
-                  u'id': 1,
-                  u'job': u'testing',
-                  u'masterid': None,
-                  u'parentid': 0,
-                  u'project': u'database.testing',
-                  u'projectpath': u'/TESTING',
-                  u'status': u'KAAAA',
-                  u'subjob': u'testJob',
-                  u'timestart': u'2016-05-02 11:31:04.253377',
-                  u'timestop': u'2016-05-02 11:31:04.371165',
-                  u'totalcputime': 0.117788,
-                  u'username': u'User'},
-                 {u'chemicalformula': u'BO',
-                  u'computer': u'localhost',
-                  u'hamilton': u'VAMPS',
-                  u'hamversion': u'1.1',
-                  u'id': 2,
-                  u'job': u'testing',
-                  u'masterid': 0,
-                  u'parentid': 0,
-                  u'project': u'database.testing',
-                  u'projectpath': u'/TESTING',
-                  u'status': u'KAAAA',
-                  u'subjob': u'testJob',
-                  u'timestart': u'2016-05-02 11:31:04.253377',
-                  u'timestop': u'2016-05-02 11:31:04.371165',
-                  u'totalcputime': 0.117788,
-                  u'username': u'User'}.....]
-        """
-
-        if where_condition:
-            where_condition = (
-                where_condition.replace("like", "similar to")
-                if self._engine.dialect.name == "postgresql"
-                else where_condition
-            )
-            try:
-                query = "select * from " + self.table_name + " where " + where_condition
-                query.replace("%", "%%")
-                result = self.conn.execute(text(query))
-            except Exception as except_msg:
-                print("EXCEPTION in get_items_sql: ", except_msg)
-                raise ValueError("EXCEPTION in get_items_sql: ", except_msg)
-        elif sql_statement:
-            sql_statement = (
-                sql_statement.replace("like", "similar to")
-                if self._engine.dialect.name == "postgresql"
-                else sql_statement
-            )
-            # TODO: make it save against SQL injection
-            result = self.conn.execute(text(sql_statement))
-        else:
-            result = self.conn.execute(text("select * from " + self.table_name))
-        row = result.mappings().all()
-        if not self._keep_connection:
-            self.conn.close()
-
-        # change the date of str datatype back into datetime object
-        output_list = []
-        for col in row:
-            # ensures working with db entries, which are camel case
-            timestop_index = [item.lower() for item in col.keys()].index("timestop")
-            timestart_index = [item.lower() for item in col.keys()].index("timestart")
-            tmp_values = list(col.values())
-            if (tmp_values[timestop_index] and tmp_values[timestart_index]) is not None:
-                # changes values
-                try:
-                    tmp_values[timestop_index] = datetime.strptime(
-                        str(tmp_values[timestop_index]), "%Y-%m-%d %H:%M:%S.%f"
-                    )
-                    tmp_values[timestart_index] = datetime.strptime(
-                        str(tmp_values[timestart_index]), "%Y-%m-%d %H:%M:%S.%f"
-                    )
-                except ValueError:
-                    print("error in: ", str(col))
-            output_list += [dict(zip(col.keys(), tmp_values))]
-        return output_list
+        )
+        self.conn.commit()
 
     def _check_chem_formula_length(self, par_dict: dict) -> dict:
         """
@@ -655,26 +553,23 @@ class DatabaseAccess(IsDatabase):
         Returns:
             int: Database ID of the item created as an int, like: 3
         """
-        if not self._view_mode:
-            try:
-                if check_duplicates and self._check_duplidates(par_dict):
-                    warnings.warn(f"Duplicate entry found in database: {par_dict}")
-                    return None
-                par_dict = self._check_chem_formula_length(par_dict)
-                par_dict = dict(
-                    (key.lower(), value) for key, value in par_dict.items()
-                )  # make keys lowercase
-                result = self.conn.execute(
-                    self.simulation_table.insert().values(**par_dict)
-                ).inserted_primary_key[-1]
-                self.conn.commit()
-                if not self._keep_connection:
-                    self.conn.close()
-                return result
-            except Exception as except_msg:
-                raise ValueError("Error occurred: " + str(except_msg))
-        else:
-            raise PermissionError("Not avilable in viewer mode.")
+        try:
+            if check_duplicates and self._check_duplidates(par_dict):
+                warnings.warn(f"Duplicate entry found in database: {par_dict}")
+                return None
+            par_dict = self._check_chem_formula_length(par_dict)
+            par_dict = dict(
+                (key.lower(), value) for key, value in par_dict.items()
+            )  # make keys lowercase
+            result = self.conn.execute(
+                self.simulation_table.insert().values(**par_dict)
+            ).inserted_primary_key[-1]
+            self.conn.commit()
+            if not self._keep_connection:
+                self.conn.close()
+            return result
+        except Exception as except_msg:
+            raise ValueError("Error occurred: " + str(except_msg))
 
     def __get_items(self, col_name: str, var: Union[str, int]) -> List[dict]:
         """
@@ -740,32 +635,29 @@ class DatabaseAccess(IsDatabase):
         Returns:
 
         """
-        if not self._view_mode:
-            if np.issubdtype(type(item_id), np.integer):
-                item_id = int(item_id)
-            # all items must be lower case, ensured here
-            par_dict = dict((key.lower(), value) for key, value in par_dict.items())
-            query = (
-                self.simulation_table.update()
-                .where(self.simulation_table.c["id"] == item_id)
-                .values()
-            )
-            try:
-                self.conn.execute(query, par_dict)
-                self.conn.commit()
-            except (OperationalError, DatabaseError):
-                if not self._sql_lite:
-                    self.conn = AutorestoredConnection(self._engine)
-                else:
-                    self.conn = self._engine.connect()
-                    self.conn.connection.create_function("like", 2, self.regexp)
+        if np.issubdtype(type(item_id), np.integer):
+            item_id = int(item_id)
+        # all items must be lower case, ensured here
+        par_dict = dict((key.lower(), value) for key, value in par_dict.items())
+        query = (
+            self.simulation_table.update()
+            .where(self.simulation_table.c["id"] == item_id)
+            .values()
+        )
+        try:
+            self.conn.execute(query, par_dict)
+            self.conn.commit()
+        except (OperationalError, DatabaseError):
+            if not self._sql_lite:
+                self.conn = AutorestoredConnection(self._engine)
+            else:
+                self.conn = self._engine.connect()
+                self.conn.connection.create_function("like", 2, self.regexp)
 
-                self.conn.execute(query, par_dict)
-                self.conn.commit()
-            if not self._keep_connection:
-                self.conn.close()
-        else:
-            raise PermissionError("Not avilable in viewer mode.")
+            self.conn.execute(query, par_dict)
+            self.conn.commit()
+        if not self._keep_connection:
+            self.conn.close()
 
     def delete_item(self, item_id: int) -> None:
         """
@@ -777,8 +669,6 @@ class DatabaseAccess(IsDatabase):
         Returns:
 
         """
-        if self._view_mode:
-            raise PermissionError("Not avilable in viewer mode.")
 
         res = self.conn.execute(
             self.simulation_table.delete().where(
@@ -900,7 +790,7 @@ class DatabaseAccess(IsDatabase):
             return_all_columns (bool): return all columns or only the 'id' - still the format stays the same.
 
         Returns:
-            list: the function returns a list of dicts like get_items_sql, but it does not format datetime:
+            list: the function returns a list of dicts, but it does not format datetime:
                  [{'chemicalformula': u'Ni108',
                   'computer': u'mapc157',
                   'hamilton': u'LAMMPS',
@@ -974,10 +864,10 @@ class DatabaseAccess(IsDatabase):
                 self.conn.connection.create_function("like", 2, self.regexp)
 
             result = self.conn.execute(query)
-        row = result.fetchall()
+        results = [row._asdict() for row in result.fetchall()]
         if not self._keep_connection:
             self.conn.close()
-        return [dict(zip(col._mapping.keys(), col._mapping.values())) for col in row]
+        return results
 
     def get_job_status(self, job_id: int) -> Union[str, None]:
         try:
