@@ -128,9 +128,9 @@ def _import_class(module_path: str, class_name: str) -> type:
             class_name,
         )
     except ImportError:
-        import pyiron_base.project.maintenance
+        import pyiron_base.maintenance.generic
 
-        if module_path in pyiron_base.project.maintenance._MODULE_CONVERSION_DICT:
+        if module_path in pyiron_base.maintenance.generic._MODULE_CONVERSION_DICT:
             raise RuntimeError(
                 f"Could not import {class_name} from {module_path}, but module path known to have changed. "
                 "Call project.maintenance.local.update_hdf_types() to upgrade storage!"
